@@ -6,10 +6,17 @@ from enumfields import EnumField
 
 class Type(Enum):
     FACEBOOK = 'facebook'
-    # TWITTER = 'twitter'
+    TWITTER = 'twitter'
+    INSTAGRAM = 'instagram'
     LINKEDIN = 'linkedin'
     EMAIL = 'email'
     GITHUB = 'github'
+    YOUTUBE = 'youtube'
+
+
+class BackgroundColor(Enum):
+    WHITE = 'white'
+    DARK = 'dark'
 
 
 class Alignment(Enum):
@@ -21,7 +28,7 @@ class Alignment(Enum):
 class SocialItemAbstract(models.Model):
     type = EnumField(Type, default=None, max_length=32, blank=False)
     order = models.PositiveIntegerField(default=0)
-    
+
     class Meta:
         abstract = True
         ordering = ['order']
@@ -31,10 +38,16 @@ class SocialItemAbstract(models.Model):
             return 'fab fa-facebook-f'
         elif self.type == Type.LINKEDIN:
             return 'fab fa-linkedin-in'
+        elif self.type == Type.TWITTER:
+            return 'fab fa-twitter'
+        elif self.type == Type.INSTAGRAM:
+            return 'fab fa-instagram'
         elif self.type == Type.EMAIL:
             return 'fas fa-envelope'
         elif self.type == Type.GITHUB:
             return 'fab fa-github'
+        elif self.type == Type.YOUTUBE:
+            return 'fab fa-youtube'
         else:
             raise ValueError()
 
@@ -48,7 +61,7 @@ class SocialShareButton(SocialItemAbstract):
         on_delete=models.CASCADE,
         related_name='items',
     )
-    
+
     class Meta(SocialItemAbstract.Meta):
         abstract = False
 
@@ -67,6 +80,7 @@ class SocialLink(SocialItemAbstract):
 
 class SocialPluginModelAbstract(CMSPlugin):
     alignment = EnumField(Alignment, default=Alignment.LEFT, max_length=32)
+    background_color = EnumField(BackgroundColor, default=BackgroundColor.DARK, max_length=32, blank=False)
     size = models.IntegerField(default=25, help_text="In pixels")
 
     class Meta:
