@@ -23,7 +23,7 @@ def item_url(context: dict, item: Union[SocialShareButton, SocialLink]):
     request: HttpRequest = context['request']
     meta = get_page_meta(request.current_page, translation.get_language())
     if item.type == Type.FACEBOOK:
-        return f'https://www.linkedin.com/sharing/share-offsite/?url={meta.url}'
+        return f'https://www.facebook.com/sharer/sharer.php?u={meta.url}'
     elif item.type == Type.LINKEDIN:
         return (
             f'https://www.linkedin.com/sharing/share-offsite/?url={meta.url}'
